"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Badge(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    text: typing.Text
    """"""

    bg_color: typing.Text
    """"""

    bg_color_night: typing.Text
    """"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        bg_color: typing.Text = ...,
        bg_color_night: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color",b"bg_color","bg_color_night",b"bg_color_night","text",b"text"]) -> None: ...
global___Badge = Badge

class CarouselImgCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTENT_STYLE_FIELD_NUMBER: builtins.int
    IMAGES_FIELD_NUMBER: builtins.int
    content_style: builtins.int
    """"""

    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CarouselImgItem]:
        """"""
        pass
    def __init__(self,
        *,
        content_style: builtins.int = ...,
        images: typing.Optional[typing.Iterable[global___CarouselImgItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_style",b"content_style","images",b"images"]) -> None: ...
global___CarouselImgCard = CarouselImgCard

class CarouselImgItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IMAGE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    TOP_TAB_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    image: typing.Text
    """"""

    uri: typing.Text
    """"""

    length: builtins.int
    """"""

    width: builtins.int
    """"""

    @property
    def top_tab(self) -> global___TopTab:
        """"""
        pass
    height: builtins.int
    """"""

    def __init__(self,
        *,
        image: typing.Text = ...,
        uri: typing.Text = ...,
        length: builtins.int = ...,
        width: builtins.int = ...,
        top_tab: typing.Optional[global___TopTab] = ...,
        height: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["top_tab",b"top_tab"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["height",b"height","image",b"image","length",b"length","top_tab",b"top_tab","uri",b"uri","width",b"width"]) -> None: ...
global___CarouselImgItem = CarouselImgItem

class CarouselWordCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTENT_STYLE_FIELD_NUMBER: builtins.int
    SCROLL_TYPE_FIELD_NUMBER: builtins.int
    WORDS_FIELD_NUMBER: builtins.int
    content_style: builtins.int
    """"""

    scroll_type: builtins.int
    """"""

    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CarouselWordItem]:
        """"""
        pass
    def __init__(self,
        *,
        content_style: builtins.int = ...,
        scroll_type: builtins.int = ...,
        words: typing.Optional[typing.Iterable[global___CarouselWordItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_style",b"content_style","scroll_type",b"scroll_type","words",b"words"]) -> None: ...
global___CarouselWordCard = CarouselWordCard

class CarouselWordItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTENT_FIELD_NUMBER: builtins.int
    content: typing.Text
    """"""

    def __init__(self,
        *,
        content: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content"]) -> None: ...
global___CarouselWordItem = CarouselWordItem

class Color(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BG_COLOR_FIELD_NUMBER: builtins.int
    TITLE_COLOR_FIELD_NUMBER: builtins.int
    TOP_FONT_COLOR_FIELD_NUMBER: builtins.int
    BOTTOM_FONT_COLOR_FIELD_NUMBER: builtins.int
    FONT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_TITLE_FONT_COLOR_FIELD_NUMBER: builtins.int
    INDICATOR_COLOR_FIELD_NUMBER: builtins.int
    CARD_BG_COLOR_FIELD_NUMBER: builtins.int
    CARD_TITLE_FONT_COLOR_FIELD_NUMBER: builtins.int
    CARD_TITLE_BG_COLOR_FIELD_NUMBER: builtins.int
    VIEW_MORE_FONT_COLOR_FIELD_NUMBER: builtins.int
    VIEW_MORE_BG_COLOR_FIELD_NUMBER: builtins.int
    TIMELINE_COLOR_FIELD_NUMBER: builtins.int
    RCMD_FONT_COLOR_FIELD_NUMBER: builtins.int
    SUBTITLE_FONT_COLOR_FIELD_NUMBER: builtins.int
    SELECTED_FONT_COLOR_FIELD_NUMBER: builtins.int
    SELECTED_BG_COLOR_FIELD_NUMBER: builtins.int
    UNSELECTED_FONT_COLOR_FIELD_NUMBER: builtins.int
    UNSELECTED_BG_COLOR_FIELD_NUMBER: builtins.int
    NT_SELECTED_FONT_COLOR_FIELD_NUMBER: builtins.int
    NT_SELECTED_BG_COLOR_FIELD_NUMBER: builtins.int
    NT_UNSELECTED_FONT_COLOR_FIELD_NUMBER: builtins.int
    NT_UNSELECTED_BG_COLOR_FIELD_NUMBER: builtins.int
    PROGRESS_BAR_COLOR_FIELD_NUMBER: builtins.int
    bg_color: typing.Text
    """"""

    title_color: typing.Text
    """"""

    top_font_color: typing.Text
    """"""

    bottom_font_color: typing.Text
    """"""

    font_color: typing.Text
    """"""

    text_title_font_color: typing.Text
    """"""

    indicator_color: typing.Text
    """"""

    card_bg_color: typing.Text
    """"""

    card_title_font_color: typing.Text
    """"""

    card_title_bg_color: typing.Text
    """"""

    view_more_font_color: typing.Text
    """"""

    view_more_bg_color: typing.Text
    """"""

    timeline_color: typing.Text
    """"""

    rcmd_font_color: typing.Text
    """"""

    subtitle_font_color: typing.Text
    """"""

    selected_font_color: typing.Text
    """"""

    selected_bg_color: typing.Text
    """"""

    unselected_font_color: typing.Text
    """"""

    unselected_bg_color: typing.Text
    """"""

    nt_selected_font_color: typing.Text
    """"""

    nt_selected_bg_color: typing.Text
    """"""

    nt_unselected_font_color: typing.Text
    """"""

    nt_unselected_bg_color: typing.Text
    """"""

    progress_bar_color: typing.Text
    """"""

    def __init__(self,
        *,
        bg_color: typing.Text = ...,
        title_color: typing.Text = ...,
        top_font_color: typing.Text = ...,
        bottom_font_color: typing.Text = ...,
        font_color: typing.Text = ...,
        text_title_font_color: typing.Text = ...,
        indicator_color: typing.Text = ...,
        card_bg_color: typing.Text = ...,
        card_title_font_color: typing.Text = ...,
        card_title_bg_color: typing.Text = ...,
        view_more_font_color: typing.Text = ...,
        view_more_bg_color: typing.Text = ...,
        timeline_color: typing.Text = ...,
        rcmd_font_color: typing.Text = ...,
        subtitle_font_color: typing.Text = ...,
        selected_font_color: typing.Text = ...,
        selected_bg_color: typing.Text = ...,
        unselected_font_color: typing.Text = ...,
        unselected_bg_color: typing.Text = ...,
        nt_selected_font_color: typing.Text = ...,
        nt_selected_bg_color: typing.Text = ...,
        nt_unselected_font_color: typing.Text = ...,
        nt_unselected_bg_color: typing.Text = ...,
        progress_bar_color: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color",b"bg_color","bottom_font_color",b"bottom_font_color","card_bg_color",b"card_bg_color","card_title_bg_color",b"card_title_bg_color","card_title_font_color",b"card_title_font_color","font_color",b"font_color","indicator_color",b"indicator_color","nt_selected_bg_color",b"nt_selected_bg_color","nt_selected_font_color",b"nt_selected_font_color","nt_unselected_bg_color",b"nt_unselected_bg_color","nt_unselected_font_color",b"nt_unselected_font_color","progress_bar_color",b"progress_bar_color","rcmd_font_color",b"rcmd_font_color","selected_bg_color",b"selected_bg_color","selected_font_color",b"selected_font_color","subtitle_font_color",b"subtitle_font_color","text_title_font_color",b"text_title_font_color","timeline_color",b"timeline_color","title_color",b"title_color","top_font_color",b"top_font_color","unselected_bg_color",b"unselected_bg_color","unselected_font_color",b"unselected_font_color","view_more_bg_color",b"view_more_bg_color","view_more_font_color",b"view_more_font_color"]) -> None: ...
global___Color = Color

class DynamicActMoreCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    SUBPAGE_DATA_FIELD_NUMBER: builtins.int
    text: typing.Text
    """"""

    uri: typing.Text
    """"""

    @property
    def subpage_data(self) -> global___SubpageData:
        """"""
        pass
    def __init__(self,
        *,
        text: typing.Text = ...,
        uri: typing.Text = ...,
        subpage_data: typing.Optional[global___SubpageData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subpage_data",b"subpage_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["subpage_data",b"subpage_data","text",b"text","uri",b"uri"]) -> None: ...
global___DynamicActMoreCard = DynamicActMoreCard

class DynamicCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DYNAMIC_FIELD_NUMBER: builtins.int
    @property
    def dynamic(self) -> bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem:
        """"""
        pass
    def __init__(self,
        *,
        dynamic: typing.Optional[bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic",b"dynamic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic",b"dynamic"]) -> None: ...
global___DynamicCard = DynamicCard

class DynamicMoreCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    SUBPAGE_DATA_FIELD_NUMBER: builtins.int
    text: typing.Text
    """"""

    uri: typing.Text
    """"""

    @property
    def subpage_data(self) -> global___SubpageData:
        """"""
        pass
    def __init__(self,
        *,
        text: typing.Text = ...,
        uri: typing.Text = ...,
        subpage_data: typing.Optional[global___SubpageData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subpage_data",b"subpage_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["subpage_data",b"subpage_data","text",b"text","uri",b"uri"]) -> None: ...
global___DynamicMoreCard = DynamicMoreCard

class DynamicParams(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FEED_OFFSET_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    LAST_GROUP_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    SORT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def feed_offset(self) -> google.protobuf.any_pb2.Any:
        """"""
        pass
    offset: builtins.int
    """"""

    last_group: builtins.int
    """"""

    module_id: builtins.int
    """"""

    sort_type: builtins.int
    """"""

    def __init__(self,
        *,
        feed_offset: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        offset: builtins.int = ...,
        last_group: builtins.int = ...,
        module_id: builtins.int = ...,
        sort_type: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feed_offset",b"feed_offset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feed_offset",b"feed_offset","last_group",b"last_group","module_id",b"module_id","offset",b"offset","sort_type",b"sort_type"]) -> None: ...
global___DynamicParams = DynamicParams

class DynamicReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RAW_PARAMS_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    IS_COLD_START_FIELD_NUMBER: builtins.int
    PRIMARY_PAGE_ID_FIELD_NUMBER: builtins.int
    raw_params: typing.Text
    """"""

    @property
    def params(self) -> global___DynamicParams:
        """"""
        pass
    from_spmid: typing.Text
    """"""

    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
        pass
    local_time: builtins.int
    """"""

    is_cold_start: builtins.bool
    """"""

    primary_page_id: builtins.int
    """"""

    def __init__(self,
        *,
        raw_params: typing.Text = ...,
        params: typing.Optional[global___DynamicParams] = ...,
        from_spmid: typing.Text = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        local_time: builtins.int = ...,
        is_cold_start: builtins.bool = ...,
        primary_page_id: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params","player_args",b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_spmid",b"from_spmid","is_cold_start",b"is_cold_start","local_time",b"local_time","params",b"params","player_args",b"player_args","primary_page_id",b"primary_page_id","raw_params",b"raw_params"]) -> None: ...
global___DynamicReq = DynamicReq

class DynamicResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULE_FIELD_NUMBER: builtins.int
    @property
    def module(self) -> global___Module:
        """"""
        pass
    def __init__(self,
        *,
        module: typing.Optional[global___Module] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module",b"module"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module",b"module"]) -> None: ...
global___DynamicResp = DynamicResp

class EditorParams(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OFFSET_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    offset: builtins.int
    """"""

    module_id: builtins.int
    """"""

    def __init__(self,
        *,
        offset: builtins.int = ...,
        module_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_id",b"module_id","offset",b"offset"]) -> None: ...
global___EditorParams = EditorParams

class EditorRecommendCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOP_ICON_FIELD_NUMBER: builtins.int
    TOP_CONTENT_FIELD_NUMBER: builtins.int
    BOTTOM_ICON_FIELD_NUMBER: builtins.int
    BOTTOM_CONTENT_FIELD_NUMBER: builtins.int
    COVER_IMAGE_URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    POSITION1_FIELD_NUMBER: builtins.int
    POSITION2_FIELD_NUMBER: builtins.int
    POSITION3_FIELD_NUMBER: builtins.int
    POSITION4_FIELD_NUMBER: builtins.int
    POSITION5_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    REPORT_DIC_FIELD_NUMBER: builtins.int
    SETTING_FIELD_NUMBER: builtins.int
    MIDDLE_ICON_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    top_icon: typing.Text
    """"""

    top_content: typing.Text
    """"""

    bottom_icon: typing.Text
    """"""

    bottom_content: typing.Text
    """"""

    cover_image_uri: typing.Text
    """"""

    title: typing.Text
    """"""

    uri: typing.Text
    """"""

    position1: typing.Text
    """"""

    position2: typing.Text
    """"""

    position3: typing.Text
    """"""

    position4: typing.Text
    """"""

    position5: typing.Text
    """"""

    @property
    def share(self) -> global___Share:
        """"""
        pass
    @property
    def badge(self) -> global___Badge:
        """"""
        pass
    @property
    def report_dic(self) -> global___ReportDic:
        """"""
        pass
    @property
    def setting(self) -> global___Setting:
        """"""
        pass
    middle_icon: typing.Text
    """"""

    resource_type: typing.Text
    """"""

    def __init__(self,
        *,
        top_icon: typing.Text = ...,
        top_content: typing.Text = ...,
        bottom_icon: typing.Text = ...,
        bottom_content: typing.Text = ...,
        cover_image_uri: typing.Text = ...,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        position1: typing.Text = ...,
        position2: typing.Text = ...,
        position3: typing.Text = ...,
        position4: typing.Text = ...,
        position5: typing.Text = ...,
        share: typing.Optional[global___Share] = ...,
        badge: typing.Optional[global___Badge] = ...,
        report_dic: typing.Optional[global___ReportDic] = ...,
        setting: typing.Optional[global___Setting] = ...,
        middle_icon: typing.Text = ...,
        resource_type: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge",b"badge","report_dic",b"report_dic","setting",b"setting","share",b"share"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","bottom_content",b"bottom_content","bottom_icon",b"bottom_icon","cover_image_uri",b"cover_image_uri","middle_icon",b"middle_icon","position1",b"position1","position2",b"position2","position3",b"position3","position4",b"position4","position5",b"position5","report_dic",b"report_dic","resource_type",b"resource_type","setting",b"setting","share",b"share","title",b"title","top_content",b"top_content","top_icon",b"top_icon","uri",b"uri"]) -> None: ...
global___EditorRecommendCard = EditorRecommendCard

class EditorReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RAW_PARAMS_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    PRIMARY_PAGE_ID_FIELD_NUMBER: builtins.int
    raw_params: typing.Text
    """"""

    @property
    def params(self) -> global___EditorParams:
        """"""
        pass
    primary_page_id: builtins.int
    """"""

    def __init__(self,
        *,
        raw_params: typing.Text = ...,
        params: typing.Optional[global___EditorParams] = ...,
        primary_page_id: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params","primary_page_id",b"primary_page_id","raw_params",b"raw_params"]) -> None: ...
global___EditorReq = EditorReq

class EditorResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULE_FIELD_NUMBER: builtins.int
    @property
    def module(self) -> global___Module:
        """"""
        pass
    def __init__(self,
        *,
        module: typing.Optional[global___Module] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module",b"module"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module",b"module"]) -> None: ...
global___EditorResp = EditorResp

class GameCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IMAGE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    image: typing.Text
    """"""

    title: typing.Text
    """"""

    uri: typing.Text
    """"""

    subtitle: typing.Text
    """"""

    content: typing.Text
    """"""

    def __init__(self,
        *,
        image: typing.Text = ...,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        subtitle: typing.Text = ...,
        content: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","image",b"image","subtitle",b"subtitle","title",b"title","uri",b"uri"]) -> None: ...
global___GameCard = GameCard

class HeaderCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    USER_IMAGE_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    SPONSOR_CONTENT_FIELD_NUMBER: builtins.int
    HIGH_LIGHT_IMAGE_FIELD_NUMBER: builtins.int
    LOW_LIGHT_IMAGE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    VIEW_NUM_FIELD_NUMBER: builtins.int
    DISCUSS_NUM_FIELD_NUMBER: builtins.int
    IS_SUBSCRIBED_FIELD_NUMBER: builtins.int
    user_image: typing.Text
    """"""

    user_name: typing.Text
    """"""

    sponsor_content: typing.Text
    """"""

    high_light_image: typing.Text
    """"""

    low_light_image: typing.Text
    """"""

    uri: typing.Text
    """"""

    view_num: typing.Text
    """"""

    discuss_num: typing.Text
    """"""

    is_subscribed: builtins.bool
    """"""

    def __init__(self,
        *,
        user_image: typing.Text = ...,
        user_name: typing.Text = ...,
        sponsor_content: typing.Text = ...,
        high_light_image: typing.Text = ...,
        low_light_image: typing.Text = ...,
        uri: typing.Text = ...,
        view_num: typing.Text = ...,
        discuss_num: typing.Text = ...,
        is_subscribed: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["discuss_num",b"discuss_num","high_light_image",b"high_light_image","is_subscribed",b"is_subscribed","low_light_image",b"low_light_image","sponsor_content",b"sponsor_content","uri",b"uri","user_image",b"user_image","user_name",b"user_name","view_num",b"view_num"]) -> None: ...
global___HeaderCard = HeaderCard

class ImageTitleCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IMAGE_FIELD_NUMBER: builtins.int
    image: typing.Text
    """"""

    def __init__(self,
        *,
        image: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image",b"image"]) -> None: ...
global___ImageTitleCard = ImageTitleCard

class IndexReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGE_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_FROM_FIELD_NUMBER: builtins.int
    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    SHARE_ORIGIN_FIELD_NUMBER: builtins.int
    TAB_ID_FIELD_NUMBER: builtins.int
    TAB_MODULE_ID_FIELD_NUMBER: builtins.int
    HTTPS_URL_REQ_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    CURRENT_TAB_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    IS_COLD_START_FIELD_NUMBER: builtins.int
    PRIMARY_PAGE_ID_FIELD_NUMBER: builtins.int
    TAB_FROM_FIELD_NUMBER: builtins.int
    page_id: builtins.int
    """"""

    activity_from: typing.Text
    """"""

    dynamic_id: builtins.int
    """"""

    share_origin: typing.Text
    """"""

    tab_id: builtins.int
    """"""

    tab_module_id: builtins.int
    """"""

    https_url_req: builtins.int
    """"""

    from_spmid: typing.Text
    """"""

    current_tab: typing.Text
    """"""

    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
        pass
    local_time: builtins.int
    """"""

    is_cold_start: builtins.bool
    """"""

    primary_page_id: builtins.int
    """"""

    tab_from: typing.Text
    """"""

    def __init__(self,
        *,
        page_id: builtins.int = ...,
        activity_from: typing.Text = ...,
        dynamic_id: builtins.int = ...,
        share_origin: typing.Text = ...,
        tab_id: builtins.int = ...,
        tab_module_id: builtins.int = ...,
        https_url_req: builtins.int = ...,
        from_spmid: typing.Text = ...,
        current_tab: typing.Text = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        local_time: builtins.int = ...,
        is_cold_start: builtins.bool = ...,
        primary_page_id: builtins.int = ...,
        tab_from: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args",b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_from",b"activity_from","current_tab",b"current_tab","dynamic_id",b"dynamic_id","from_spmid",b"from_spmid","https_url_req",b"https_url_req","is_cold_start",b"is_cold_start","local_time",b"local_time","page_id",b"page_id","player_args",b"player_args","primary_page_id",b"primary_page_id","share_origin",b"share_origin","tab_from",b"tab_from","tab_id",b"tab_id","tab_module_id",b"tab_module_id"]) -> None: ...
global___IndexReq = IndexReq

class InlineIndexReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGE_ID_FIELD_NUMBER: builtins.int
    HTTPS_URL_REQ_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    IS_COLD_START_FIELD_NUMBER: builtins.int
    page_id: builtins.int
    https_url_req: builtins.int
    """"""

    from_spmid: typing.Text
    """"""

    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
        pass
    local_time: builtins.int
    """"""

    is_cold_start: builtins.bool
    """"""

    def __init__(self,
        *,
        page_id: builtins.int = ...,
        https_url_req: builtins.int = ...,
        from_spmid: typing.Text = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        local_time: builtins.int = ...,
        is_cold_start: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args",b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_spmid",b"from_spmid","https_url_req",b"https_url_req","is_cold_start",b"is_cold_start","local_time",b"local_time","page_id",b"page_id","player_args",b"player_args"]) -> None: ...
global___InlineIndexReq = InlineIndexReq

class LayerDynamic(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    DYNAMIC_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    @property
    def dynamic(self) -> bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem:
        """"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        dynamic: typing.Optional[bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic",b"dynamic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic",b"dynamic","title",b"title"]) -> None: ...
global___LayerDynamic = LayerDynamic

class LiveCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HAS_LIVE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    has_live: builtins.int
    """"""

    @property
    def content(self) -> global___LiveItem:
        """"""
        pass
    def __init__(self,
        *,
        has_live: builtins.int = ...,
        content: typing.Optional[global___LiveItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content",b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","has_live",b"has_live"]) -> None: ...
global___LiveCard = LiveCard

class LiveItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_ID_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    LIVE_STATUS_FIELD_NUMBER: builtins.int
    ROOM_TYPE_FIELD_NUMBER: builtins.int
    PLAY_TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    AREA_ID_FIELD_NUMBER: builtins.int
    AREA_NAME_FIELD_NUMBER: builtins.int
    PARENT_AREA_ID_FIELD_NUMBER: builtins.int
    PARENT_AREA_NAME_FIELD_NUMBER: builtins.int
    LIVE_SCREEN_TYPE_FIELD_NUMBER: builtins.int
    LAST_END_TIME_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    LIVE_ID_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """"""

    uid: builtins.int
    """"""

    live_status: builtins.int
    """"""

    room_type: builtins.int
    """"""

    play_type: builtins.int
    """"""

    title: typing.Text
    """"""

    cover: typing.Text
    """"""

    online: builtins.int
    """"""

    area_id: builtins.int
    """"""

    area_name: typing.Text
    """"""

    parent_area_id: builtins.int
    """"""

    parent_area_name: typing.Text
    """"""

    live_screen_type: builtins.int
    """"""

    last_end_time: builtins.int
    """"""

    link: typing.Text
    """"""

    live_id: builtins.int
    """"""

    def __init__(self,
        *,
        room_id: builtins.int = ...,
        uid: builtins.int = ...,
        live_status: builtins.int = ...,
        room_type: builtins.int = ...,
        play_type: builtins.int = ...,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        online: builtins.int = ...,
        area_id: builtins.int = ...,
        area_name: typing.Text = ...,
        parent_area_id: builtins.int = ...,
        parent_area_name: typing.Text = ...,
        live_screen_type: builtins.int = ...,
        last_end_time: builtins.int = ...,
        link: typing.Text = ...,
        live_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["area_id",b"area_id","area_name",b"area_name","cover",b"cover","last_end_time",b"last_end_time","link",b"link","live_id",b"live_id","live_screen_type",b"live_screen_type","live_status",b"live_status","online",b"online","parent_area_id",b"parent_area_id","parent_area_name",b"parent_area_name","play_type",b"play_type","room_id",b"room_id","room_type",b"room_type","title",b"title","uid",b"uid"]) -> None: ...
global___LiveItem = LiveItem

class Module(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULE_TYPE_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    MODULE_COLOR_FIELD_NUMBER: builtins.int
    MODULE_SETTING_FIELD_NUMBER: builtins.int
    MODULE_ITEMS_FIELD_NUMBER: builtins.int
    SUBPAGE_PARAMS_FIELD_NUMBER: builtins.int
    MODULE_UKEY_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    IS_FEED_FIELD_NUMBER: builtins.int
    module_type: typing.Text
    """"""

    module_id: builtins.int
    """"""

    @property
    def module_color(self) -> global___Color:
        """"""
        pass
    @property
    def module_setting(self) -> global___Setting:
        """"""
        pass
    @property
    def module_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleItem]:
        """"""
        pass
    subpage_params: typing.Text
    """"""

    module_ukey: typing.Text
    """"""

    has_more: builtins.bool
    """"""

    is_feed: builtins.bool
    """"""

    def __init__(self,
        *,
        module_type: typing.Text = ...,
        module_id: builtins.int = ...,
        module_color: typing.Optional[global___Color] = ...,
        module_setting: typing.Optional[global___Setting] = ...,
        module_items: typing.Optional[typing.Iterable[global___ModuleItem]] = ...,
        subpage_params: typing.Text = ...,
        module_ukey: typing.Text = ...,
        has_more: builtins.bool = ...,
        is_feed: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_color",b"module_color","module_setting",b"module_setting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more",b"has_more","is_feed",b"is_feed","module_color",b"module_color","module_id",b"module_id","module_items",b"module_items","module_setting",b"module_setting","module_type",b"module_type","module_ukey",b"module_ukey","subpage_params",b"subpage_params"]) -> None: ...
global___Module = Module

class ModuleItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CARD_TYPE_FIELD_NUMBER: builtins.int
    CARD_ID_FIELD_NUMBER: builtins.int
    EDITOR_RECOMMEND_CARD_FIELD_NUMBER: builtins.int
    PARTICIPATION_CARD_FIELD_NUMBER: builtins.int
    HEADER_CARD_FIELD_NUMBER: builtins.int
    DYNAMIC_CARD_FIELD_NUMBER: builtins.int
    TEXT_CARD_FIELD_NUMBER: builtins.int
    TEXT_TITLE_CARD_FIELD_NUMBER: builtins.int
    IMAGE_TITLE_CARD_FIELD_NUMBER: builtins.int
    DYNAMIC_MORE_CARD_FIELD_NUMBER: builtins.int
    DYNAMIC_ACT_MORE_CARD_FIELD_NUMBER: builtins.int
    LIVE_CARD_FIELD_NUMBER: builtins.int
    CAROUSEL_IMG_CARD_FIELD_NUMBER: builtins.int
    CAROUSEL_WORD_CARD_FIELD_NUMBER: builtins.int
    RESOURCE_CARD_FIELD_NUMBER: builtins.int
    RESOURCE_MORE_CARD_FIELD_NUMBER: builtins.int
    GAME_CARD_FIELD_NUMBER: builtins.int
    VIDEO_CARD_FIELD_NUMBER: builtins.int
    VIDEO_MORE_CARD_FIELD_NUMBER: builtins.int
    card_type: typing.Text
    """"""

    card_id: typing.Text
    """"""

    @property
    def editor_recommend_card(self) -> global___EditorRecommendCard:
        """"""
        pass
    @property
    def participation_card(self) -> global___ParticipationCard:
        """"""
        pass
    @property
    def header_card(self) -> global___HeaderCard:
        """"""
        pass
    @property
    def dynamic_card(self) -> global___DynamicCard:
        """"""
        pass
    @property
    def text_card(self) -> global___TextCard:
        """"""
        pass
    @property
    def text_title_card(self) -> global___TextTitleCard:
        """"""
        pass
    @property
    def image_title_card(self) -> global___ImageTitleCard:
        """"""
        pass
    @property
    def dynamic_more_card(self) -> global___DynamicMoreCard:
        """"""
        pass
    @property
    def dynamic_act_more_card(self) -> global___DynamicActMoreCard:
        """"""
        pass
    @property
    def live_card(self) -> global___LiveCard:
        """"""
        pass
    @property
    def carousel_img_card(self) -> global___CarouselImgCard:
        """"""
        pass
    @property
    def carousel_word_card(self) -> global___CarouselWordCard:
        """"""
        pass
    @property
    def resource_card(self) -> global___ResourceCard:
        """"""
        pass
    @property
    def resource_more_card(self) -> global___ResourceMoreCard:
        """"""
        pass
    @property
    def game_card(self) -> global___GameCard:
        """"""
        pass
    @property
    def video_card(self) -> global___VideoCard:
        """"""
        pass
    @property
    def video_more_card(self) -> global___VideoMoreCard:
        """"""
        pass
    def __init__(self,
        *,
        card_type: typing.Text = ...,
        card_id: typing.Text = ...,
        editor_recommend_card: typing.Optional[global___EditorRecommendCard] = ...,
        participation_card: typing.Optional[global___ParticipationCard] = ...,
        header_card: typing.Optional[global___HeaderCard] = ...,
        dynamic_card: typing.Optional[global___DynamicCard] = ...,
        text_card: typing.Optional[global___TextCard] = ...,
        text_title_card: typing.Optional[global___TextTitleCard] = ...,
        image_title_card: typing.Optional[global___ImageTitleCard] = ...,
        dynamic_more_card: typing.Optional[global___DynamicMoreCard] = ...,
        dynamic_act_more_card: typing.Optional[global___DynamicActMoreCard] = ...,
        live_card: typing.Optional[global___LiveCard] = ...,
        carousel_img_card: typing.Optional[global___CarouselImgCard] = ...,
        carousel_word_card: typing.Optional[global___CarouselWordCard] = ...,
        resource_card: typing.Optional[global___ResourceCard] = ...,
        resource_more_card: typing.Optional[global___ResourceMoreCard] = ...,
        game_card: typing.Optional[global___GameCard] = ...,
        video_card: typing.Optional[global___VideoCard] = ...,
        video_more_card: typing.Optional[global___VideoMoreCard] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card_detail",b"card_detail","carousel_img_card",b"carousel_img_card","carousel_word_card",b"carousel_word_card","dynamic_act_more_card",b"dynamic_act_more_card","dynamic_card",b"dynamic_card","dynamic_more_card",b"dynamic_more_card","editor_recommend_card",b"editor_recommend_card","game_card",b"game_card","header_card",b"header_card","image_title_card",b"image_title_card","live_card",b"live_card","participation_card",b"participation_card","resource_card",b"resource_card","resource_more_card",b"resource_more_card","text_card",b"text_card","text_title_card",b"text_title_card","video_card",b"video_card","video_more_card",b"video_more_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_detail",b"card_detail","card_id",b"card_id","card_type",b"card_type","carousel_img_card",b"carousel_img_card","carousel_word_card",b"carousel_word_card","dynamic_act_more_card",b"dynamic_act_more_card","dynamic_card",b"dynamic_card","dynamic_more_card",b"dynamic_more_card","editor_recommend_card",b"editor_recommend_card","game_card",b"game_card","header_card",b"header_card","image_title_card",b"image_title_card","live_card",b"live_card","participation_card",b"participation_card","resource_card",b"resource_card","resource_more_card",b"resource_more_card","text_card",b"text_card","text_title_card",b"text_title_card","video_card",b"video_card","video_more_card",b"video_more_card"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["card_detail",b"card_detail"]) -> typing.Optional[typing_extensions.Literal["editor_recommend_card","participation_card","header_card","dynamic_card","text_card","text_title_card","image_title_card","dynamic_more_card","dynamic_act_more_card","live_card","carousel_img_card","carousel_word_card","resource_card","resource_more_card","game_card","video_card","video_more_card"]]: ...
global___ModuleItem = ModuleItem

class PageResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_ONLINE_FIELD_NUMBER: builtins.int
    IGNORE_APP_DARK_THEME_FIELD_NUMBER: builtins.int
    PAGE_COLOR_FIELD_NUMBER: builtins.int
    PAGE_SHARE_FIELD_NUMBER: builtins.int
    PAGE_HEADER_FIELD_NUMBER: builtins.int
    PARTICIPATION_FIELD_NUMBER: builtins.int
    MODULE_LIST_FIELD_NUMBER: builtins.int
    IS_DYNAMIC_FEED_FIELD_NUMBER: builtins.int
    LAYER_DYNAMIC_FIELD_NUMBER: builtins.int
    IS_EDITOR_FEED_FIELD_NUMBER: builtins.int
    SPONSOR_TYPE_FIELD_NUMBER: builtins.int
    TOP_TAB_FIELD_NUMBER: builtins.int
    is_online: builtins.bool
    """"""

    ignore_app_dark_theme: builtins.bool
    """"""

    @property
    def page_color(self) -> global___Color:
        """"""
        pass
    @property
    def page_share(self) -> global___PageShare:
        """"""
        pass
    @property
    def page_header(self) -> global___Module:
        """"""
        pass
    @property
    def participation(self) -> global___Module:
        """"""
        pass
    @property
    def module_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Module]:
        """"""
        pass
    is_dynamic_feed: builtins.bool
    """"""

    @property
    def layer_dynamic(self) -> global___LayerDynamic:
        """"""
        pass
    is_editor_feed: builtins.bool
    """"""

    sponsor_type: builtins.int
    """"""

    @property
    def top_tab(self) -> global___TopTab:
        """"""
        pass
    def __init__(self,
        *,
        is_online: builtins.bool = ...,
        ignore_app_dark_theme: builtins.bool = ...,
        page_color: typing.Optional[global___Color] = ...,
        page_share: typing.Optional[global___PageShare] = ...,
        page_header: typing.Optional[global___Module] = ...,
        participation: typing.Optional[global___Module] = ...,
        module_list: typing.Optional[typing.Iterable[global___Module]] = ...,
        is_dynamic_feed: builtins.bool = ...,
        layer_dynamic: typing.Optional[global___LayerDynamic] = ...,
        is_editor_feed: builtins.bool = ...,
        sponsor_type: builtins.int = ...,
        top_tab: typing.Optional[global___TopTab] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["layer_dynamic",b"layer_dynamic","page_color",b"page_color","page_header",b"page_header","page_share",b"page_share","participation",b"participation","top_tab",b"top_tab"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ignore_app_dark_theme",b"ignore_app_dark_theme","is_dynamic_feed",b"is_dynamic_feed","is_editor_feed",b"is_editor_feed","is_online",b"is_online","layer_dynamic",b"layer_dynamic","module_list",b"module_list","page_color",b"page_color","page_header",b"page_header","page_share",b"page_share","participation",b"participation","sponsor_type",b"sponsor_type","top_tab",b"top_tab"]) -> None: ...
global___PageResp = PageResp

class PageShare(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    INSIDE_URI_FIELD_NUMBER: builtins.int
    OUTSIDE_URI_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""

    title: typing.Text
    """"""

    desc: typing.Text
    """"""

    image: typing.Text
    """"""

    inside_uri: typing.Text
    """"""

    outside_uri: typing.Text
    """"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        title: typing.Text = ...,
        desc: typing.Text = ...,
        image: typing.Text = ...,
        inside_uri: typing.Text = ...,
        outside_uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","image",b"image","inside_uri",b"inside_uri","outside_uri",b"outside_uri","title",b"title","type",b"type"]) -> None: ...
global___PageShare = PageShare

class ParticipationCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IMAGE_FIELD_NUMBER: builtins.int
    SELECTED_IMAGE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    image: typing.Text
    """"""

    selected_image: typing.Text
    """"""

    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ParticipationCardItem]:
        """"""
        pass
    def __init__(self,
        *,
        image: typing.Text = ...,
        selected_image: typing.Text = ...,
        items: typing.Optional[typing.Iterable[global___ParticipationCardItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image",b"image","items",b"items","selected_image",b"selected_image"]) -> None: ...
global___ParticipationCard = ParticipationCard

class ParticipationCardItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IMAGE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    image: typing.Text
    """"""

    uri: typing.Text
    """"""

    title: typing.Text
    """"""

    type: typing.Text
    """"""

    def __init__(self,
        *,
        image: typing.Text = ...,
        uri: typing.Text = ...,
        title: typing.Text = ...,
        type: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image",b"image","title",b"title","type",b"type","uri",b"uri"]) -> None: ...
global___ParticipationCardItem = ParticipationCardItem

class PlayerDimension(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    width: builtins.int
    """"""

    height: builtins.int
    """"""

    rotate: builtins.bool
    """"""

    def __init__(self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        rotate: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height",b"height","rotate",b"rotate","width",b"width"]) -> None: ...
global___PlayerDimension = PlayerDimension

class ReportDic(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SUB_TYPE_FIELD_NUMBER: builtins.int
    EP_ID_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    AUTHOR_NAME_FIELD_NUMBER: builtins.int
    biz_type: typing.Text
    """"""

    season_type: typing.Text
    """"""

    aid: builtins.int
    """"""

    cid: builtins.int
    """"""

    sub_type: builtins.int
    """"""

    ep_id: builtins.int
    """"""

    is_preview: builtins.int
    """"""

    season_id: builtins.int
    """"""

    author_name: typing.Text
    """"""

    def __init__(self,
        *,
        biz_type: typing.Text = ...,
        season_type: typing.Text = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        sub_type: builtins.int = ...,
        ep_id: builtins.int = ...,
        is_preview: builtins.int = ...,
        season_id: builtins.int = ...,
        author_name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","author_name",b"author_name","biz_type",b"biz_type","cid",b"cid","ep_id",b"ep_id","is_preview",b"is_preview","season_id",b"season_id","season_type",b"season_type","sub_type",b"sub_type"]) -> None: ...
global___ReportDic = ReportDic

class ResourceCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    COVER_IMAGE_URI_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON2_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    REPORT_DIC_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    cover_image_uri: typing.Text
    """"""

    uri: typing.Text
    """"""

    cover_right_text: typing.Text
    """"""

    cover_left_text1: typing.Text
    """"""

    cover_left_icon1: builtins.int
    """"""

    cover_left_text2: typing.Text
    """"""

    cover_left_icon2: builtins.int
    """"""

    @property
    def badge(self) -> global___Badge:
        """"""
        pass
    @property
    def report_dic(self) -> global___ReportDic:
        """"""
        pass
    resource_type: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        cover_image_uri: typing.Text = ...,
        uri: typing.Text = ...,
        cover_right_text: typing.Text = ...,
        cover_left_text1: typing.Text = ...,
        cover_left_icon1: builtins.int = ...,
        cover_left_text2: typing.Text = ...,
        cover_left_icon2: builtins.int = ...,
        badge: typing.Optional[global___Badge] = ...,
        report_dic: typing.Optional[global___ReportDic] = ...,
        resource_type: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge",b"badge","report_dic",b"report_dic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","cover_image_uri",b"cover_image_uri","cover_left_icon1",b"cover_left_icon1","cover_left_icon2",b"cover_left_icon2","cover_left_text1",b"cover_left_text1","cover_left_text2",b"cover_left_text2","cover_right_text",b"cover_right_text","report_dic",b"report_dic","resource_type",b"resource_type","title",b"title","uri",b"uri"]) -> None: ...
global___ResourceCard = ResourceCard

class ResourceMoreCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    SUBPAGE_DATA_FIELD_NUMBER: builtins.int
    text: typing.Text
    """"""

    uri: typing.Text
    """"""

    @property
    def subpage_data(self) -> global___SubpageData:
        """"""
        pass
    def __init__(self,
        *,
        text: typing.Text = ...,
        uri: typing.Text = ...,
        subpage_data: typing.Optional[global___SubpageData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subpage_data",b"subpage_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["subpage_data",b"subpage_data","text",b"text","uri",b"uri"]) -> None: ...
global___ResourceMoreCard = ResourceMoreCard

class ResourceParams(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OFFSET_FIELD_NUMBER: builtins.int
    TOPIC_OFFSET_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    SORT_TYPE_FIELD_NUMBER: builtins.int
    offset: builtins.int
    """"""

    topic_offset: typing.Text
    """"""

    module_id: builtins.int
    """"""

    sort_type: builtins.int
    """"""

    def __init__(self,
        *,
        offset: builtins.int = ...,
        topic_offset: typing.Text = ...,
        module_id: builtins.int = ...,
        sort_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_id",b"module_id","offset",b"offset","sort_type",b"sort_type","topic_offset",b"topic_offset"]) -> None: ...
global___ResourceParams = ResourceParams

class ResourceReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RAW_PARAMS_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    PRIMARY_PAGE_ID_FIELD_NUMBER: builtins.int
    raw_params: typing.Text
    """"""

    @property
    def params(self) -> global___ResourceParams:
        """"""
        pass
    primary_page_id: builtins.int
    """"""

    def __init__(self,
        *,
        raw_params: typing.Text = ...,
        params: typing.Optional[global___ResourceParams] = ...,
        primary_page_id: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params","primary_page_id",b"primary_page_id","raw_params",b"raw_params"]) -> None: ...
global___ResourceReq = ResourceReq

class ResourceResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULE_FIELD_NUMBER: builtins.int
    @property
    def module(self) -> global___Module:
        """"""
        pass
    def __init__(self,
        *,
        module: typing.Optional[global___Module] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module",b"module"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module",b"module"]) -> None: ...
global___ResourceResp = ResourceResp

class Setting(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DISPLAY_MORE_BUTTON_FIELD_NUMBER: builtins.int
    DISPLAY_TITLE_FIELD_NUMBER: builtins.int
    AUTO_CAROUSEL_FIELD_NUMBER: builtins.int
    TOP_TAB_FOLLOW_IMG_FIELD_NUMBER: builtins.int
    TOP_TAB_FADE_AWAY_FIELD_NUMBER: builtins.int
    AUTO_PLAY_FIELD_NUMBER: builtins.int
    DISPLAY_UNFOLD_BUTTON_FIELD_NUMBER: builtins.int
    DISPLAY_NUM_FIELD_NUMBER: builtins.int
    DISPLAY_VIEW_NUM_FIELD_NUMBER: builtins.int
    DISPLAY_SUBSCRIBE_BTN_FIELD_NUMBER: builtins.int
    UNFOLD_REST_FIELD_NUMBER: builtins.int
    DISPLAY_PROGRESS_NUM_FIELD_NUMBER: builtins.int
    DISPLAY_NODE_NUM_FIELD_NUMBER: builtins.int
    DISPLAY_NODE_DESC_FIELD_NUMBER: builtins.int
    display_more_button: builtins.bool
    """"""

    display_title: builtins.bool
    """"""

    auto_carousel: builtins.bool
    """"""

    top_tab_follow_img: builtins.bool
    """"""

    top_tab_fade_away: builtins.bool
    """"""

    auto_play: builtins.bool
    """"""

    display_unfold_button: builtins.bool
    """"""

    display_num: builtins.bool
    """"""

    display_view_num: builtins.bool
    """"""

    display_subscribe_btn: builtins.bool
    """"""

    unfold_rest: builtins.bool
    """"""

    display_progress_num: builtins.bool
    """"""

    display_node_num: builtins.bool
    """"""

    display_node_desc: builtins.bool
    """"""

    def __init__(self,
        *,
        display_more_button: builtins.bool = ...,
        display_title: builtins.bool = ...,
        auto_carousel: builtins.bool = ...,
        top_tab_follow_img: builtins.bool = ...,
        top_tab_fade_away: builtins.bool = ...,
        auto_play: builtins.bool = ...,
        display_unfold_button: builtins.bool = ...,
        display_num: builtins.bool = ...,
        display_view_num: builtins.bool = ...,
        display_subscribe_btn: builtins.bool = ...,
        unfold_rest: builtins.bool = ...,
        display_progress_num: builtins.bool = ...,
        display_node_num: builtins.bool = ...,
        display_node_desc: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_carousel",b"auto_carousel","auto_play",b"auto_play","display_more_button",b"display_more_button","display_node_desc",b"display_node_desc","display_node_num",b"display_node_num","display_num",b"display_num","display_progress_num",b"display_progress_num","display_subscribe_btn",b"display_subscribe_btn","display_title",b"display_title","display_unfold_button",b"display_unfold_button","display_view_num",b"display_view_num","top_tab_fade_away",b"top_tab_fade_away","top_tab_follow_img",b"top_tab_follow_img","unfold_rest",b"unfold_rest"]) -> None: ...
global___Setting = Setting

class Share(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DISPLAY_LATER_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    SHARE_ORIGIN_FIELD_NUMBER: builtins.int
    SHARE_TYPE_FIELD_NUMBER: builtins.int
    display_later: builtins.bool
    """"""

    oid: builtins.int
    """"""

    share_origin: typing.Text
    """"""

    share_type: builtins.int
    """"""

    def __init__(self,
        *,
        display_later: builtins.bool = ...,
        oid: builtins.int = ...,
        share_origin: typing.Text = ...,
        share_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_later",b"display_later","oid",b"oid","share_origin",b"share_origin","share_type",b"share_type"]) -> None: ...
global___Share = Share

class SubpageData(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    TABS_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    params: typing.Text
    """"""

    @property
    def tabs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubpageTab]:
        """"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        params: typing.Text = ...,
        tabs: typing.Optional[typing.Iterable[global___SubpageTab]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params","tabs",b"tabs","title",b"title"]) -> None: ...
global___SubpageData = SubpageData

class SubpageTab(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    name: typing.Text
    """"""

    params: typing.Text
    """"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        params: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name","params",b"params"]) -> None: ...
global___SubpageTab = SubpageTab

class TabIndexReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGE_ID_FIELD_NUMBER: builtins.int
    HTTPS_URL_REQ_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    PRIMARY_PAGE_ID_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    IS_COLD_START_FIELD_NUMBER: builtins.int
    page_id: builtins.int
    """"""

    https_url_req: builtins.int
    """"""

    from_spmid: typing.Text
    """"""

    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
        pass
    primary_page_id: builtins.int
    """"""

    local_time: builtins.int
    """"""

    is_cold_start: builtins.bool
    """"""

    def __init__(self,
        *,
        page_id: builtins.int = ...,
        https_url_req: builtins.int = ...,
        from_spmid: typing.Text = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        primary_page_id: builtins.int = ...,
        local_time: builtins.int = ...,
        is_cold_start: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args",b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_spmid",b"from_spmid","https_url_req",b"https_url_req","is_cold_start",b"is_cold_start","local_time",b"local_time","page_id",b"page_id","player_args",b"player_args","primary_page_id",b"primary_page_id"]) -> None: ...
global___TabIndexReq = TabIndexReq

class TextCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    text: typing.Text
    """"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text",b"text"]) -> None: ...
global___TextCard = TextCard

class TextTitleCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["title",b"title"]) -> None: ...
global___TextTitleCard = TextTitleCard

class TopTab(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BG_IMAGE1_FIELD_NUMBER: builtins.int
    BG_IMAGE2_FIELD_NUMBER: builtins.int
    TAB_TOP_COLOR_FIELD_NUMBER: builtins.int
    TAB_MIDDLE_COLOR_FIELD_NUMBER: builtins.int
    TAB_BOTTOM_COLOR_FIELD_NUMBER: builtins.int
    FONT_COLOR_FIELD_NUMBER: builtins.int
    BAR_TYPE_FIELD_NUMBER: builtins.int
    bg_image1: typing.Text
    """"""

    bg_image2: typing.Text
    """"""

    tab_top_color: typing.Text
    """"""

    tab_middle_color: typing.Text
    """"""

    tab_bottom_color: typing.Text
    """"""

    font_color: typing.Text
    """"""

    bar_type: builtins.int
    """"""

    def __init__(self,
        *,
        bg_image1: typing.Text = ...,
        bg_image2: typing.Text = ...,
        tab_top_color: typing.Text = ...,
        tab_middle_color: typing.Text = ...,
        tab_bottom_color: typing.Text = ...,
        font_color: typing.Text = ...,
        bar_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bar_type",b"bar_type","bg_image1",b"bg_image1","bg_image2",b"bg_image2","font_color",b"font_color","tab_bottom_color",b"tab_bottom_color","tab_middle_color",b"tab_middle_color","tab_top_color",b"tab_top_color"]) -> None: ...
global___TopTab = TopTab

class TopicIndexReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGE_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_FROM_FIELD_NUMBER: builtins.int
    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    SHARE_ORIGIN_FIELD_NUMBER: builtins.int
    TAB_ID_FIELD_NUMBER: builtins.int
    TAB_MODULE_ID_FIELD_NUMBER: builtins.int
    HTTPS_URL_REQ_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    CURRENT_TAB_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    IS_COLD_START_FIELD_NUMBER: builtins.int
    page_id: builtins.int
    """"""

    activity_from: typing.Text
    """"""

    dynamic_id: builtins.int
    """"""

    share_origin: typing.Text
    """"""

    tab_id: builtins.int
    """"""

    tab_module_id: builtins.int
    """"""

    https_url_req: builtins.int
    """"""

    from_spmid: typing.Text
    """"""

    current_tab: typing.Text
    """"""

    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
        pass
    local_time: builtins.int
    """"""

    is_cold_start: builtins.bool
    """"""

    def __init__(self,
        *,
        page_id: builtins.int = ...,
        activity_from: typing.Text = ...,
        dynamic_id: builtins.int = ...,
        share_origin: typing.Text = ...,
        tab_id: builtins.int = ...,
        tab_module_id: builtins.int = ...,
        https_url_req: builtins.int = ...,
        from_spmid: typing.Text = ...,
        current_tab: typing.Text = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        local_time: builtins.int = ...,
        is_cold_start: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args",b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_from",b"activity_from","current_tab",b"current_tab","dynamic_id",b"dynamic_id","from_spmid",b"from_spmid","https_url_req",b"https_url_req","is_cold_start",b"is_cold_start","local_time",b"local_time","page_id",b"page_id","player_args",b"player_args","share_origin",b"share_origin","tab_id",b"tab_id","tab_module_id",b"tab_module_id"]) -> None: ...
global___TopicIndexReq = TopicIndexReq

class VideoCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    COVER_IMAGE_URI_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT3_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    REPORT_DIC_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    cover_image_uri: typing.Text
    """"""

    cover_left_text1: typing.Text
    """"""

    cover_left_text2: typing.Text
    """"""

    cover_left_text3: typing.Text
    """"""

    uri: typing.Text
    """"""

    @property
    def badge(self) -> global___Badge:
        """"""
        pass
    @property
    def rights(self) -> global___VideoRights:
        """"""
        pass
    @property
    def dimension(self) -> global___PlayerDimension:
        """"""
        pass
    @property
    def report_dic(self) -> global___ReportDic:
        """"""
        pass
    resource_type: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        cover_image_uri: typing.Text = ...,
        cover_left_text1: typing.Text = ...,
        cover_left_text2: typing.Text = ...,
        cover_left_text3: typing.Text = ...,
        uri: typing.Text = ...,
        badge: typing.Optional[global___Badge] = ...,
        rights: typing.Optional[global___VideoRights] = ...,
        dimension: typing.Optional[global___PlayerDimension] = ...,
        report_dic: typing.Optional[global___ReportDic] = ...,
        resource_type: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge",b"badge","dimension",b"dimension","report_dic",b"report_dic","rights",b"rights"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","cover_image_uri",b"cover_image_uri","cover_left_text1",b"cover_left_text1","cover_left_text2",b"cover_left_text2","cover_left_text3",b"cover_left_text3","dimension",b"dimension","report_dic",b"report_dic","resource_type",b"resource_type","rights",b"rights","title",b"title","uri",b"uri"]) -> None: ...
global___VideoCard = VideoCard

class VideoMoreCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    SUBPAGE_DATA_FIELD_NUMBER: builtins.int
    text: typing.Text
    uri: typing.Text
    """"""

    @property
    def subpage_data(self) -> global___SubpageData:
        """"""
        pass
    def __init__(self,
        *,
        text: typing.Text = ...,
        uri: typing.Text = ...,
        subpage_data: typing.Optional[global___SubpageData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subpage_data",b"subpage_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["subpage_data",b"subpage_data","text",b"text","uri",b"uri"]) -> None: ...
global___VideoMoreCard = VideoMoreCard

class VideoParams(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OFFSET_FIELD_NUMBER: builtins.int
    TOPIC_OFFSET_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    SORT_TYPE_FIELD_NUMBER: builtins.int
    offset: builtins.int
    """"""

    topic_offset: typing.Text
    """"""

    module_id: builtins.int
    """"""

    sort_type: builtins.int
    """"""

    def __init__(self,
        *,
        offset: builtins.int = ...,
        topic_offset: typing.Text = ...,
        module_id: builtins.int = ...,
        sort_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_id",b"module_id","offset",b"offset","sort_type",b"sort_type","topic_offset",b"topic_offset"]) -> None: ...
global___VideoParams = VideoParams

class VideoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RAW_PARAMS_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    PRIMARY_PAGE_ID_FIELD_NUMBER: builtins.int
    raw_params: typing.Text
    """"""

    @property
    def params(self) -> global___VideoParams:
        """"""
        pass
    primary_page_id: builtins.int
    """"""

    def __init__(self,
        *,
        raw_params: typing.Text = ...,
        params: typing.Optional[global___VideoParams] = ...,
        primary_page_id: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params","primary_page_id",b"primary_page_id","raw_params",b"raw_params"]) -> None: ...
global___VideoReq = VideoReq

class VideoResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULE_FIELD_NUMBER: builtins.int
    @property
    def module(self) -> global___Module:
        """"""
        pass
    def __init__(self,
        *,
        module: typing.Optional[global___Module] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module",b"module"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module",b"module"]) -> None: ...
global___VideoResp = VideoResp

class VideoRights(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UGC_PAY_FIELD_NUMBER: builtins.int
    IS_COOPERATION_FIELD_NUMBER: builtins.int
    IS_PGC_FIELD_NUMBER: builtins.int
    ugc_pay: builtins.bool
    """"""

    is_cooperation: builtins.bool
    """"""

    is_pgc: builtins.bool
    """"""

    def __init__(self,
        *,
        ugc_pay: builtins.bool = ...,
        is_cooperation: builtins.bool = ...,
        is_pgc: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_cooperation",b"is_cooperation","is_pgc",b"is_pgc","ugc_pay",b"ugc_pay"]) -> None: ...
global___VideoRights = VideoRights
